# D-rex

Dynamic replication for heterogeneous storage nodes.

Maxime GONTHIER - Dante - Haochen


First start a virtual environment.

```bash
python3 -m venv venv  
. venv/bin/activate
```

Install requirements:

```
pip install -e .
```

Execution:

```bash
python3 -m test.drex-test    
```

(sudo if not in editable repository ;))
